@@ -24,7 +24,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.7.0';
+our $VERSION = '3.7.2';
 
 =head1 SYNOPSIS
 
@@ -524,6 +524,35 @@ sub _extract_from_invidious {
     return @formats;
 }
 
+sub _extract_from_ytdl {
+    my ($self, $videoID) = @_;
+
+    ((state $x = system('youtube-dl', '--version')) == 0) || return;
+
+    my $json = $self->proxy_stdout('youtube-dl', '--all-formats', '--dump-single-json',
+                                   quotemeta("https://www.youtube.com/watch?v=" . $videoID));
+
+    my $ref = $self->parse_json_string($json);
+
+    my @formats;
+    if (ref($ref) eq 'HASH' and exists($ref->{formats}) and ref($ref->{formats}) eq 'ARRAY') {
+        foreach my $format (@{$ref->{formats}}) {
+            if (exists($format->{format_id}) and exists($format->{url})) {
+
+                my $entry = {
+                             itag => $format->{format_id},
+                             url  => $format->{url},
+                             type => ((($format->{format_note} // '') eq 'DASH audio') ? 'audio/' : 'video/') . $format->{ext},
+                            };
+
+                push @formats, $entry;
+            }
+        }
+    }
+
+    return @formats;
+}
+
 sub _fallback_extract_urls {
     my ($self, $videoID) = @_;
 
@@ -544,31 +573,11 @@ sub _fallback_extract_urls {
         @formats && return @formats;
     }
 
-    ((state $x = system('youtube-dl', '--version')) == 0) || return;
-
     if ($self->get_debug) {
         say STDERR ":: Using youtube-dl to extract the streaming URLs...";
     }
 
-    my $json = $self->proxy_stdout('youtube-dl', '--all-formats', '--dump-single-json',
-                                   quotemeta("https://www.youtube.com/watch?v=" . $videoID));
-
-    my $ref = $self->parse_json_string($json) // return;
-
-    if (ref($ref) eq 'HASH' and exists($ref->{formats}) and ref($ref->{formats}) eq 'ARRAY') {
-        foreach my $format (@{$ref->{formats}}) {
-            if (exists($format->{format_id}) and exists($format->{url})) {
-
-                my $entry = {
-                             itag => $format->{format_id},
-                             url  => $format->{url},
-                             type => ((($format->{format_note} // '') eq 'DASH audio') ? 'audio/' : 'video/') . $format->{ext},
-                            };
-
-                push @formats, $entry;
-            }
-        }
-    }
+    push @formats, $self->_extract_from_ytdl($videoID);
 
     if ($self->get_debug) {
         my $count = scalar(@formats);
@@ -721,13 +730,15 @@ sub _extract_streaming_urls {
         say STDERR ":: Using `player_response` to extract the streaming URLs...";
     }
 
-    my $json = $self->parse_json_string($info->{player_response});
+    my $json = $self->parse_json_string($info->{player_response} // return);
 
     if ($self->get_debug >= 2) {
         require Data::Dump;
         Data::Dump::pp($json);
     }
 
+    ref($json) eq 'HASH' or return;
+
     my @results;
     if (exists $json->{streamingData}) {
 
@@ -796,6 +807,16 @@ sub _extract_streaming_urls {
     return @results;
 }
 
+sub _get_video_info {
+    my ($self, $videoID) = @_;
+
+    my $url     = $self->get_video_info_url() . sprintf($self->get_video_info_args(), $videoID);
+    my $content = $self->lwp_get($url, simple => 1) // return;
+    my %info    = $self->parse_query_string($content);
+
+    return %info;
+}
+
 =head2 get_streaming_urls($videoID)
 
 Returns a list of streaming URLs for a videoID.
@@ -806,10 +827,7 @@ Returns a list of streaming URLs for a videoID.
 sub get_streaming_urls {
     my ($self, $videoID) = @_;
 
-    my $url     = ($self->get_video_info_url() . sprintf($self->get_video_info_args(), $videoID));
-    my $content = $self->lwp_get($url, simple => 1) // return;
-    my %info    = $self->parse_query_string($content);
-
+    my %info           = $self->_get_video_info($videoID);
     my @streaming_urls = $self->_extract_streaming_urls(\%info, $videoID);
 
     my @caption_urls;
