@@ -202,15 +202,15 @@ sub date_to_age {
     return join(' ', $year - $+{year}, 'years');
 }
 
-=head2 has_entries($request)
+=head2 has_entries($result)
 
-Returns true if a given request has entries.
+Returns true if a given result has entries.
 
 =cut
 
 sub has_entries {
-    my ($self, $req) = @_;
-    !!$req->{results}{pageInfo}{totalResults};
+    my ($self, $result) = @_;
+    ref($result) eq 'HASH' and ($result->{results}{pageInfo}{totalResults} > 0);
 }
 
 =head2 normalize_video_title($title, $fat32safe)
@@ -266,6 +266,7 @@ sub format_text {
         DEFINITION  => sub { $self->get_definition($info) },
         DIMENSION   => sub { $self->get_dimension($info) },
         VIEWS       => sub { $self->get_views($info) },
+        VIEWS_SHORT => sub { $self->get_views_approx($info) },
         LIKES       => sub { $self->get_likes($info) },
         DISLIKES    => sub { $self->get_dislikes($info) },
         COMMENTS    => sub { $self->get_comments($info) },
@@ -276,6 +277,7 @@ sub format_text {
         CAPTION     => sub { $self->get_caption($info) },
         PUBLISHED   => sub { $self->get_publication_date($info) },
         AGE         => sub { $self->get_publication_age($info) },
+        AGE_SHORT   => sub { $self->get_publication_age_approx($info) },
         DESCRIPTION => sub { $self->get_description($info) },
 
         RATING => sub {
@@ -502,6 +504,30 @@ sub get_publication_age {
     return $age;
 }
 
+sub get_publication_age_approx {
+    my ($self, $info) = @_;
+
+    my $age = $self->date_to_age($info->{snippet}{publishedAt});
+
+    if ($age =~ /hour|minute|second/) {
+        return "0d";
+    }
+
+    if ($age =~ /^(\d+) day/) {
+        return "$1d";
+    }
+
+    if ($age =~ /^(\d+) month/) {
+        return "$1m";
+    }
+
+    if ($age =~ /^(\d+) year/) {
+        return "$1y";
+    }
+
+    return $age;
+}
+
 sub get_duration {
     my ($self, $info) = @_;
     $self->format_duration($info->{contentDetails}{duration});
@@ -534,7 +560,42 @@ sub get_caption {
 
 sub get_views {
     my ($self, $info) = @_;
-    $info->{statistics}{viewCount};
+    $info->{statistics}{viewCount} // 0;
+}
+
+sub get_views_approx {
+    my ($self, $info) = @_;
+    my $views = $info->{statistics}{viewCount} // 0;
+
+    if ($views < 1000) {
+        return $views;
+    }
+
+    if ($views >= 10 * 1e9) {    # ten billions
+        return sprintf("%dB", int($views / 1e9));
+    }
+
+    if ($views >= 1e9) {         # billions
+        return sprintf("%.2gB", $views / 1e9);
+    }
+
+    if ($views >= 10 * 1e6) {    # ten millions
+        return sprintf("%dM", int($views / 1e6));
+    }
+
+    if ($views >= 1e6) {         # millions
+        return sprintf("%.2gM", $views / 1e6);
+    }
+
+    if ($views >= 10 * 1e3) {    # ten thousands
+        return sprintf("%dK", int($views / 1e3));
+    }
+
+    if ($views >= 1e3) {         # thousands
+        return sprintf("%.2gK", $views / 1e3);
+    }
+
+    return $views;
 }
 
 sub get_likes {
@@ -585,7 +646,7 @@ sub get_comments {
 sub is_channelID {
     my ($self, $id) = @_;
     $id || return;
-    $id =~ /^UC[-a-zA-Z0-9_]{22}\z/;
+    $id eq 'mine' or $id =~ /^UC[-a-zA-Z0-9_]{22}\z/;
 }
 
 sub is_videoID {
